@@ -7,15 +7,16 @@ from pymysql.cursors import DictCursor
 mysql = 'mysql'
 sqlite = 'sqlite'
 
-danger_sig = ['--','-+','#']
+danger_sig = ['--', '-+', '#']
 
 ENGINE_DICT = {
-    'mysql':pymysql,
-    'sqlite':sqlite3
+    'mysql': pymysql,
+    'sqlite': sqlite3
 }
 
+
 class Base(object):
-    def __init__(self, host, user, psw, dbname,engine,charset):
+    def __init__(self, host, user, psw, dbname, engine, charset):
         self.id = id(self)
         self._host = host
         self._user = user
@@ -47,13 +48,13 @@ class Base(object):
 
     def connect(self):
         if self._engine == mysql:
-            self.db = self.db_engine.connect(self._host, self._user, self._psw, self._dbname, charset=self._charset,connect_timeout=60)
+            self.db = self.db_engine.connect(self._host, self._user, self._psw, self._dbname, charset=self._charset,
+                                             connect_timeout=60)
             return self.db
         if self._engine == sqlite:
             self.db = self.db_engine.connect(self._dbname)
             return self.db
 
-
     def become_busy(self):
         self._is_busy = 1
         self.last_execute_time = int(time.time())
@@ -81,16 +82,15 @@ class Base(object):
         if self._engine != sqlite:
             self.query('select 1')
 
-
     def load_an_table(self, table):
         if self._engine == sqlite:
-            sql = 'PRAGMA table_info(%s)'%table
+            sql = 'PRAGMA table_info(%s)' % table
         else:
-            sql = 'show fields from ' +table
+            sql = 'show fields from ' + table
         res = self.query(sql, show_sql=False)
         if res is None:
             return
-        column_list = list(map(lambda x: x[0],res))
+        column_list = list(map(lambda x: x[0], res))
         if 'signal' in column_list:
             column_list.remove('signal')
         self._tables[table] = column_list
@@ -101,16 +101,16 @@ class Base(object):
         sql = 'show tables'
         res = self.query(sql, show_sql)
         # print(res)
-        tables = list(map(lambda x: x[0],res))
+        tables = list(map(lambda x: x[0], res))
         # print(tables)
         for table in tables:
-            table_name = self._dbname+'.'+table
+            table_name = self._dbname + '.' + table
             self.load_an_table(table_name)
 
     def _load_all_fileds(self):
         pass
 
-    def create(self, table, colums, table_comment='',show_sql=False):
+    def create(self, table, colums, table_comment='', show_sql=False):
         sql = 'create table %s(' % table
 
         tail = ''
@@ -118,7 +118,7 @@ class Base(object):
         for item in colums:
             col = ''
             if self._engine == sqlite:
-                item= item[:-1]
+                item = item[:-1]
             for i in item:
                 col += str(i)
                 col += ' '
@@ -128,22 +128,22 @@ class Base(object):
         tail = tail[:-1] + ')'
         sql += tail
         if self._engine == mysql:
-            sql += 'charset=utf8mb4,engine=innodb,comment="%s"'%(table_comment)
+            sql += 'charset=utf8mb4,engine=innodb,comment="%s"' % table_comment
         if self._engine == sqlite:
-            sql = sql.replace('int AUTO_INCREMENT primary key','INTEGER PRIMARY KEY AUTOINCREMENT')
+            sql = sql.replace('int AUTO_INCREMENT primary key', 'INTEGER PRIMARY KEY AUTOINCREMENT')
         self.query(sql, show_sql)
         self.commit()
         return
 
     @staticmethod
-    def find_info(table, conditions, or_cond, fields=None, group=None, order=None, limit=None,for_update=False):
+    def find_info(table, conditions, or_cond, fields=None, group=None, order=None, limit=None, for_update=False):
 
         if fields is None:
             return
 
-        sql = 'select %s from %s where  '%(','.join(fields), table)
+        sql = 'select %s from %s where  ' % (','.join(fields), table)
         # print(sql)
-        sql,sql_params = Base.bind_conditions(sql, conditions, or_cond)
+        sql, sql_params = Base.bind_conditions(sql, conditions, or_cond)
 
         if group is not None:
             sql += 'group by '
@@ -162,7 +162,6 @@ class Base(object):
                 count += 1
             sql = sql[:-1]
 
-
         if limit is not None:
             sql += 'limit '
             for i in limit:
@@ -181,16 +180,16 @@ class Base(object):
         if or_cond is None:
             or_cond = []
         if len(or_cond) + len(conditions) == 0:
-            return sql[:-7],None
+            return sql[:-7], None
 
         if len(conditions) > 0:
             for unit in conditions:
                 value = unit[2]
-                sql = sql + " %s %s binary "%(unit[0], unit[1]) + '%s'
+                sql = sql + " %s %s binary " % (unit[0], unit[1]) + '%s'
                 sql_params += [value]
                 sql += "  and "
                 if 'in' in unit[1]:
-                    sql = sql.replace('binary','')
+                    sql = sql.replace('binary', '')
             sql = sql[:-4]
             if len(or_cond) > 0:
                 sql += ' or '
@@ -198,17 +197,17 @@ class Base(object):
         if len(or_cond) > 0:
             for unit in or_cond:
                 value = unit[2]
-                sql = sql + " %s %s binary "%(unit[0], unit[1]) + '%s'
+                sql = sql + " %s %s binary " % (unit[0], unit[1]) + '%s'
                 sql_params += [value]
                 sql += "  or "
                 if 'in' in unit[1]:
-                    sql = sql.replace('binary','')
+                    sql = sql.replace('binary', '')
             sql = sql[:-3]
 
-        return sql,sql_params
+        return sql, sql_params
 
     # 查找数据（单条）
-    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False,for_update=False):
+    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False, for_update=False):
         if table not in self._tables:
             self.load_an_table(table)
 
@@ -216,13 +215,13 @@ class Base(object):
             fieldList = self._tables[table]
             fields = fieldList
 
-        sql,sql_params = self.find_info(table, conditions, or_cond, fields, None, order, None,for_update)
+        sql, sql_params = self.find_info(table, conditions, or_cond, fields, None, order, None, for_update)
         if sql is None:
             return
 
         sql += " limit 1"
         # self.db.commit()
-        res = self.query(sql, show_sql,sql_params,return_dict=True)
+        res = self.query(sql, show_sql, sql_params, return_dict=True)
         if res is None:
             return None
 
@@ -235,14 +234,15 @@ class Base(object):
             result = res[0]
 
         result = {
-            'table':table,
-            'query':sql%tuple(sql_params) if sql_params is not None else sql,
-            'result':result
+            'table': table,
+            'query': sql % tuple(sql_params) if sql_params is not None else sql,
+            'result': result
         }
         return result
 
     # 查找数据
-    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,for_update=False):
+    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,
+               for_update=False):
         if table not in self._tables:
             self.load_an_table(table)
 
@@ -250,11 +250,11 @@ class Base(object):
             fieldList = self._tables[table]
             fields = fieldList
 
-        sql,sql_params = self.find_info(table, conditions, or_cond, fields, group, order, limit,for_update)
+        sql, sql_params = self.find_info(table, conditions, or_cond, fields, group, order, limit, for_update)
         if sql is None:
             return
         #
-        res = self.query(sql, show_sql,sql_params,return_dict=True)
+        res = self.query(sql, show_sql, sql_params, return_dict=True)
         if res is None:
             return None
 
@@ -270,7 +270,7 @@ class Base(object):
             result = res
         res = {
             'table': table,
-            'query': sql%tuple(sql_params) if sql_params is not None else sql,
+            'query': sql % tuple(sql_params) if sql_params is not None else sql,
             'result': result
         }
         return res
@@ -283,17 +283,17 @@ class Base(object):
             keys = keys[:-2] + ")"
         sql_params = []
         sql = 'insert into %s%s values (' % (table, keys)
-        for i in  params.values():
+        for i in params.values():
             sql_params.append(i)
         for _ in params.values():
             sql += '%s,'
         sql = sql[:-1]
         sql += ')'
         #
-        self.query(sql, show_sql,sql_params)
+        self.query(sql, show_sql, sql_params)
         return
 
-    def update(self, table, conditions, or_cond, params,show_sql=False):
+    def update(self, table, conditions, or_cond, params, show_sql=False):
         # print('开始执行')
         if params == {} or params is None:
             # print('没有params，结束执行')
@@ -305,43 +305,43 @@ class Base(object):
             sql_params_header += [value]
 
         sql = sql[:-1] + ' where  '
-        sql,sql_params = Base.bind_conditions(sql, conditions, or_cond)
+        sql, sql_params = Base.bind_conditions(sql, conditions, or_cond)
         # print(sql)
-        if sql_params == None:
+        if sql_params is None:
             sql_params = []
         sql_params = sql_params_header + sql_params
 
-        self.query(sql, show_sql,sql_params)
-            # print('自动提交完毕')
+        self.query(sql, show_sql, sql_params)
+        # print('自动提交完毕')
         return
 
     def delete(self, table, condition, or_cond, show_sql=False):
-        sql = 'delete from %s where  ' %table
-        sql,sql_params = Base.bind_conditions(sql, condition, or_cond)
+        sql = 'delete from %s where  ' % table
+        sql, sql_params = Base.bind_conditions(sql, condition, or_cond)
         #  #
-        self.query(sql, show_sql,sql_params)
+        self.query(sql, show_sql, sql_params)
         return
 
-    def query(self, sql, show_sql=False,sql_params=None,return_dict=False):
+    def query(self, sql, show_sql=False, sql_params=None, return_dict=False):
         # for i in danger_sig:
         #     if i in sql:
         #         return None
-        dummy_sql = sql%tuple(sql_params) if sql_params is not None else sql
+        dummy_sql = sql % tuple(sql_params) if sql_params is not None else sql
         if self._engine == sqlite:
-            sql = sql.replace('binary','')
+            sql = sql.replace('binary', '')
             sql = sql.replace('%s', '?')
         self.executing_query = dummy_sql
         if sql == 'select 1':
             show_sql = False
         if show_sql is True:
-            print('sql_id',id(self),dummy_sql)
+            print('sql_id', id(self), dummy_sql)
         if self._engine != sqlite:
             try:
                 self.db.ping(reconnect=True)
             except Exception as e:
                 print(dummy_sql, 'db error', str(e), 'reconnecting...')
                 self.connect()
-        if self._engine == mysql and return_dict == True:
+        if self._engine == mysql and return_dict is True:
             cursor = self.db.cursor(DictCursor)
         else:
             cursor = self.db.cursor()
@@ -351,7 +351,7 @@ class Base(object):
                 self.update_last_execute_time()
                 self.update_last_connect_time()
             if sql_params is not None:
-                cursor.execute(sql,tuple(sql_params))
+                cursor.execute(sql, tuple(sql_params))
             else:
                 cursor.execute(sql)
             results = cursor.fetchall()
