@@ -5,6 +5,7 @@ import time
 # from ..Scheduler import IntervalTask
 from ..dbserver.base import Base, ENGINE_DICT, mysql
 
+
 # from config.config import db_config
 def dump_table(table, sql):
     if sql.is_busy():
@@ -14,6 +15,7 @@ def dump_table(table, sql):
     sql.become_free()
     return result
 
+
 class data_manager(object):
     keep_cycle = 10
 
@@ -35,12 +37,11 @@ class data_manager(object):
         # IntervalTask(data_manager.keep_cycle, self.keep_connect)
         self.mem_cache = {}
 
-
-    def get_table_name(self,table_name):
+    def get_table_name(self, table_name):
         if '.' in table_name:
             return table_name
         else:
-            return self.t_data['database']+'.'+table_name
+            return self.t_data['database'] + '.' + table_name
 
     def keep_connect(self):
         pass
@@ -73,7 +74,6 @@ class data_manager(object):
         #         sql.keep_connect()
         #         sql.become_free()
 
-
     # def kill_unused_connection(self, kill_connect):
     #     count = 0
     #     for sql_id in kill_connect:
@@ -82,23 +82,25 @@ class data_manager(object):
     #             count += 1
     #     return
 
-    def get_table_data(self,table,query):
+    def get_table_data(self, table, query):
         try:
             return self.mem_cache[table][query]
-        except:
+        except Exception as e:
+            print(str(e))
             return None
 
-    def clean_table(self,table):
+    def clean_table(self, table):
         try:
             return self.mem_cache.pop(table) if table in self.mem_cache else None
-        except:
+        except Exception as e:
+            print(str(e))
             return None
 
     def find_free_sql(self):
         # 获取当前线程绑定的sql-session
         mypid = str(os.getpid())
         mytid = str(threading.currentThread().ident)
-        thread_id = mypid+'.'+mytid
+        thread_id = mypid + '.' + mytid
         # print('本次数据库请求线程id', thread_id)
         if thread_id in self.threading_pool:
             session_status = self.threading_pool[thread_id]
@@ -111,7 +113,7 @@ class data_manager(object):
         session = self.create_new_sql()
         session.become_busy()
         # self.add_new_sql(sql)
-        self.threading_pool[thread_id] = (session,int(time.time()))
+        self.threading_pool[thread_id] = (session, int(time.time()))
         # self.threading_out_time_pool[thread_id] = int(time.time())
         # print('为线程%s更新数据库链接%s'%(thread_id,id(sql)))
         return session
@@ -127,16 +129,17 @@ class data_manager(object):
         return sql
 
     def create_new_sql(self, ):
-        sql = Base(self.t_data['host'], self.t_data['user'], self.t_data['password'], self.t_data['database'],self.t_data['engine'],self.t_data['charset'])
+        sql = Base(self.t_data['host'], self.t_data['user'], self.t_data['password'], self.t_data['database'],
+                   self.t_data['engine'], self.t_data['charset'])
         # sql.become_busy()
         # self.sql_pool.append(sql)
         return sql
 
-    def create(self, table, colums, table_comment = '',show_sql=False):
+    def create(self, table, colums, table_comment='', show_sql=False):
         sql = self.find_free_sql()
         # sql.become_busy()
         # print('执行这次sql请求的链接是', id(sql))
-        result = sql.create(table, colums, table_comment,show_sql)
+        result = sql.create(table, colums, table_comment, show_sql)
         sql.become_free()
         return result
 
@@ -150,18 +153,19 @@ class data_manager(object):
         self.clean_table(table)
         return result
 
-    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False,from_cache = False,for_update=False):
+    def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False, from_cache=False,
+             for_update=False):
         sql = self.find_free_sql()
         table = self.get_table_name(table)
-        if from_cache == True:
-            query,params = sql.find_info(table, conditions, or_cond, fields, None, order, None,for_update)
+        if from_cache is True:
+            query, params = sql.find_info(table, conditions, or_cond, fields, None, order, None, for_update)
             query += " limit 1"
-            query = query%params
-            res = self.get_table_data(table,query)
+            query = query % params
+            res = self.get_table_data(table, query)
             if res is not None:
                 sql.become_free()
                 return res
-        result = sql.find(table, conditions, or_cond, fields, order, show_sql,for_update)
+        result = sql.find(table, conditions, or_cond, fields, order, show_sql, for_update)
         if result is None:
             return
         self.mem_cache[table] = {
@@ -170,29 +174,30 @@ class data_manager(object):
         sql.become_free()
         return result['result']
 
-    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,from_cache=False,for_update=False):
+    def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,
+               from_cache=False, for_update=False):
         sql = self.find_free_sql()
         table = self.get_table_name(table)
         # sql.become_busy()
         # print('执行这次sql请求的链接是', id(sql))
-        if from_cache == True:
-            query,params = sql.find_info(table, conditions, or_cond, fields, group, order, limit,for_update)
+        if from_cache is True:
+            query, params = sql.find_info(table, conditions, or_cond, fields, group, order, limit, for_update)
             query = query % params
             res = self.get_table_data(table, query)
             if res is not None:
                 sql.become_free()
                 return res
 
-        result = sql.select(table, conditions, or_cond, fields, group, order, limit, show_sql,for_update)
+        result = sql.select(table, conditions, or_cond, fields, group, order, limit, show_sql, for_update)
         if result is None:
             return
         self.mem_cache[table] = {
-            result['query']:result['result']
+            result['query']: result['result']
         }
         sql.become_free()
         return result['result']
 
-    def update(self, table, conditions,or_cond, params, show_sql=False):
+    def update(self, table, conditions, or_cond, params, show_sql=False):
         sql = self.find_free_sql()
         table = self.get_table_name(table)
         # sql.become_busy()
@@ -208,17 +213,17 @@ class data_manager(object):
         table = self.get_table_name(table)
         # sql.become_busy()
         # print('执行这次sql请求的链接是', id(sql))
-        result = sql.delete(table, conditions, or_cond,  show_sql)
+        result = sql.delete(table, conditions, or_cond, show_sql)
         self.clean_table(table)
         sql.become_free()
         return result
 
-    def query(self, sql_query, show_sql=False,return_dict=False):
+    def query(self, sql_query, show_sql=False, return_dict=False):
         # print(sql)
         sql = self.find_free_sql()
         # sql.become_busy()
         # print('执行这次sql请求的链接是', id(sql))
-        result = sql.query(sql_query, show_sql,return_dict=return_dict)
+        result = sql.query(sql_query, show_sql, return_dict=return_dict)
         sql.become_free()
         return result
 
